# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/baserun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x10v1/baserun.proto\x12\nbaserun.v1\x1a\x1fgoogle/protobuf/timestamp.proto"\x9c\x01\n\x06Status\x12\x0f\n\x07message\x18\x01 \x01(\t\x12+\n\x04\x63ode\x18\x02 \x01(\x0e\x32\x1d.baserun.v1.Status.StatusCode"T\n\nStatusCode\x12\x1b\n\x17STATUS_CODE_UNSPECIFIED\x10\x00\x12\x12\n\x0eSTATUS_CODE_OK\x10\x01\x12\x15\n\x11STATUS_CODE_ERROR\x10\x02"/\n\x0cToolFunction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\targuments\x18\x02 \x01(\t"P\n\x08ToolCall\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12*\n\x08\x66unction\x18\x03 \x01(\x0b\x32\x18.baserun.v1.ToolFunction"\xc0\x01\n\x07Message\x12\x0c\n\x04role\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x15\n\rfinish_reason\x18\x03 \x01(\t\x12\x15\n\rfunction_call\x18\x04 \x01(\t\x12(\n\ntool_calls\x18\x05 \x03(\x0b\x32\x14.baserun.v1.ToolCall\x12\x14\n\x0ctool_call_id\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x1a\n\x12system_fingerprint\x18\x08 \x01(\t"\x85\x03\n\x03Run\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x10\n\x08suite_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06inputs\x18\x04 \x03(\t\x12)\n\x08run_type\x18\x05 \x01(\x0e\x32\x17.baserun.v1.Run.RunType\x12\x10\n\x08metadata\x18\x06 \x01(\t\x12\x33\n\x0fstart_timestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x14\x63ompletion_timestamp\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06result\x18\t \x01(\t\x12\r\n\x05\x65rror\x18\n \x01(\t\x12\x12\n\nsession_id\x18\x0b \x01(\t\x12\x18\n\x0b\x65nvironment\x18\x0c \x01(\tH\x00\x88\x01\x01"5\n\x07RunType\x12\x11\n\rRUN_TYPE_TEST\x10\x00\x12\x17\n\x13RUN_TYPE_PRODUCTION\x10\x01\x42\x0e\n\x0c_environment"c\n\x03Log\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07payload\x18\x03 \x01(\t\x12-\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp")\n\x07\x45ndUser\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nidentifier\x18\x02 \x01(\t"G\n\x05Model\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nmodel_name\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t"\xf3\x01\n\x0bModelConfig\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x10\n\x08model_id\x18\x02 \x01(\x05\x12 \n\x05model\x18\x03 \x01(\x0b\x32\x11.baserun.v1.Model\x12\x12\n\nlogit_bias\x18\x04 \x01(\t\x12\x18\n\x10presence_penalty\x18\x05 \x01(\x02\x12\x19\n\x11\x66requency_penalty\x18\x06 \x01(\x02\x12\x13\n\x0btemperature\x18\x07 \x01(\x02\x12\r\n\x05top_p\x18\x08 \x01(\x02\x12\r\n\x05top_k\x18\t \x01(\x02\x12\x11\n\tfunctions\x18\n \x01(\t\x12\x15\n\rfunction_call\x18\x0b \x01(\t"\xa5\r\n\x04Span\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x10\n\x08trace_id\x18\x02 \x01(\x0c\x12\x0f\n\x07span_id\x18\x03 \x01(\x04\x12\x0c\n\x04name\x18\x04 \x01(\t\x12.\n\nstart_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12"\n\x06status\x18\x07 \x01(\x0b\x32\x12.baserun.v1.Status\x12\x0e\n\x06vendor\x18\x08 \x01(\t\x12\x14\n\x0crequest_type\x18\t \x01(\t\x12\r\n\x05model\x18\n \x01(\t\x12\x14\n\x0ctotal_tokens\x18\x0b \x01(\x05\x12\x19\n\x11\x63ompletion_tokens\x18\x0c \x01(\x05\x12\x15\n\rprompt_tokens\x18\r \x01(\x05\x12,\n\x0fprompt_messages\x18\x0e \x03(\x0b\x32\x13.baserun.v1.Message\x12(\n\x0b\x63ompletions\x18\x0f \x03(\x0b\x32\x13.baserun.v1.Message\x12\x15\n\x08\x61pi_base\x18\x10 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08\x61pi_type\x18\x11 \x01(\tH\x01\x88\x01\x01\x12\x16\n\tfunctions\x18\x12 \x01(\tH\x02\x88\x01\x01\x12\x1a\n\rfunction_call\x18\x13 \x01(\tH\x03\x88\x01\x01\x12\x18\n\x0btemperature\x18\x14 \x01(\x01H\x04\x88\x01\x01\x12\x12\n\x05top_p\x18\x15 \x01(\x01H\x05\x88\x01\x01\x12\x0e\n\x01n\x18\x16 \x01(\x05H\x06\x88\x01\x01\x12\x13\n\x06stream\x18\x17 \x01(\x08H\x07\x88\x01\x01\x12\x0c\n\x04stop\x18\x18 \x03(\t\x12\x17\n\nmax_tokens\x18\x19 \x01(\x05H\x08\x88\x01\x01\x12\x1d\n\x10presence_penalty\x18\x1a \x01(\x01H\t\x88\x01\x01\x12\x1e\n\x11\x66requency_penalty\x18\x1b \x01(\x01H\n\x88\x01\x01\x12\x17\n\nlogit_bias\x18\x1c \x01(\tH\x0b\x88\x01\x01\x12\x11\n\x04user\x18\x1d \x01(\tH\x0c\x88\x01\x01\x12\x15\n\x08logprobs\x18\x1e \x01(\x05H\r\x88\x01\x01\x12\x11\n\x04\x65\x63ho\x18\x1f \x01(\x08H\x0e\x88\x01\x01\x12\x13\n\x06suffix\x18  \x01(\tH\x0f\x88\x01\x01\x12\x14\n\x07\x62\x65st_of\x18! \x01(\x05H\x10\x88\x01\x01\x12\x19\n\x0cx_request_id\x18/ \x01(\tH\x11\x88\x01\x01\x12\x13\n\x06log_id\x18" \x01(\tH\x12\x88\x01\x01\x12\x12\n\x05top_k\x18# \x01(\x01H\x13\x88\x01\x01\x12%\n\x08\x65nd_user\x18$ \x01(\x0b\x32\x13.baserun.v1.EndUser\x12\x18\n\x0btemplate_id\x18% \x01(\tH\x14\x88\x01\x01\x12 \n\x13template_parameters\x18& \x01(\tH\x15\x88\x01\x01\x12\x1c\n\x0ftemplate_string\x18- \x01(\tH\x16\x88\x01\x01\x12 \n\x13template_version_id\x18. \x01(\tH\x17\x88\x01\x01\x12\x1a\n\rtemplate_name\x18\x30 \x01(\tH\x18\x88\x01\x01\x12\x12\n\x05tools\x18\' \x01(\tH\x19\x88\x01\x01\x12\x18\n\x0btool_choice\x18( \x01(\tH\x1a\x88\x01\x01\x12\x11\n\x04seed\x18) \x01(\x05H\x1b\x88\x01\x01\x12\x1c\n\x0fresponse_format\x18* \x01(\tH\x1c\x88\x01\x01\x12\x1d\n\x10\x65rror_stacktrace\x18+ \x01(\tH\x1d\x88\x01\x01\x12\x1a\n\rcompletion_id\x18, \x01(\tH\x1e\x88\x01\x01\x42\x0b\n\t_api_baseB\x0b\n\t_api_typeB\x0c\n\n_functionsB\x10\n\x0e_function_callB\x0e\n\x0c_temperatureB\x08\n\x06_top_pB\x04\n\x02_nB\t\n\x07_streamB\r\n\x0b_max_tokensB\x13\n\x11_presence_penaltyB\x14\n\x12_frequency_penaltyB\r\n\x0b_logit_biasB\x07\n\x05_userB\x0b\n\t_logprobsB\x07\n\x05_echoB\t\n\x07_suffixB\n\n\x08_best_ofB\x0f\n\r_x_request_idB\t\n\x07_log_idB\x08\n\x06_top_kB\x0e\n\x0c_template_idB\x16\n\x14_template_parametersB\x12\n\x10_template_stringB\x16\n\x14_template_version_idB\x10\n\x0e_template_nameB\x08\n\x06_toolsB\x0e\n\x0c_tool_choiceB\x07\n\x05_seedB\x12\n\x10_response_formatB\x13\n\x11_error_stacktraceB\x10\n\x0e_completion_id"u\n\x04\x45val\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0e\n\x06result\x18\x03 \x01(\t\x12\x12\n\x05score\x18\x05 \x01(\x01H\x00\x88\x01\x01\x12\x12\n\nsubmission\x18\x06 \x01(\t\x12\x0f\n\x07payload\x18\x07 \x01(\tB\x08\n\x06_score"m\n\x05\x43heck\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bmethodology\x18\x02 \x01(\t\x12\x10\n\x08\x65xpected\x18\x03 \x01(\t\x12\x0e\n\x06\x61\x63tual\x18\x04 \x01(\t\x12\r\n\x05score\x18\x05 \x01(\x01\x12\x10\n\x08metadata\x18\x06 \x01(\t"`\n\x08\x46\x65\x65\x64\x62\x61\x63k\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x01\x12\x10\n\x08metadata\x18\x03 \x01(\t\x12%\n\x08\x65nd_user\x18\x04 \x01(\x0b\x32\x13.baserun.v1.EndUser"\xcc\x01\n\x15\x43ompletionAnnotations\x12\x15\n\rcompletion_id\x18\x01 \x01(\t\x12!\n\x06\x63hecks\x18\x02 \x03(\x0b\x32\x11.baserun.v1.Check\x12\x1d\n\x04logs\x18\x03 \x03(\x0b\x32\x0f.baserun.v1.Log\x12&\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x04 \x03(\x0b\x32\x14.baserun.v1.Feedback\x12\x32\n\x0finput_variables\x18\x05 \x03(\x0b\x32\x19.baserun.v1.InputVariable"\x94\x01\n\tTestSuite\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x33\n\x0fstart_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x14\x63ompletion_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp"\xd0\x02\n\x08Template\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x38\n\rtemplate_type\x18\x03 \x01(\x0e\x32!.baserun.v1.Template.TemplateType\x12\x36\n\x11template_versions\x18\x04 \x03(\x0b\x32\x1b.baserun.v1.TemplateVersion\x12\x38\n\x0e\x61\x63tive_version\x18\x05 \x01(\x0b\x32\x1b.baserun.v1.TemplateVersionH\x00\x88\x01\x01"k\n\x0cTemplateType\x12\x1d\n\x19TEMPLATE_TYPE_UNSPECIFIED\x10\x00\x12"\n\x1eTEMPLATE_TYPE_FORMATTED_STRING\x10\x01\x12\x18\n\x14TEMPLATE_TYPE_JINJA2\x10\x02\x42\x11\n\x0f_active_version"\xf8\x01\n\x0fTemplateVersion\x12\n\n\x02id\x18\x01 \x01(\t\x12&\n\x08template\x18\x02 \x01(\x0b\x32\x14.baserun.v1.Template\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12!\n\x14parameter_definition\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x1c\n\x0ftemplate_string\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\x36\n\x11template_messages\x18\x06 \x03(\x0b\x32\x1b.baserun.v1.TemplateMessageB\x17\n\x15_parameter_definitionB\x12\n\x10_template_string"\x88\x01\n\x0fTemplateMessage\x12\n\n\x02id\x18\x01 \x01(\t\x12\x35\n\x10template_version\x18\x02 \x01(\x0b\x32\x1b.baserun.v1.TemplateVersion\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0c\n\x04role\x18\x04 \x01(\t\x12\x13\n\x0border_index\x18\x05 \x01(\x05"\xbf\x01\n\x07Session\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nidentifier\x18\x02 \x01(\t\x12\x33\n\x0fstart_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x14\x63ompletion_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12%\n\x08\x65nd_user\x18\x05 \x01(\x0b\x32\x13.baserun.v1.EndUser"\xab\x01\n\rInputVariable\x12\n\n\x02id\x18\x01 \x01(\t\x12\x18\n\x0btemplate_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0ctest_case_id\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\t\x12\x12\n\x05label\x18\x06 \x01(\tH\x02\x88\x01\x01\x42\x0e\n\x0c_template_idB\x0f\n\r_test_case_idB\x08\n\x06_label"/\n\x0fStartRunRequest\x12\x1c\n\x03run\x18\x01 \x01(\x0b\x32\x0f.baserun.v1.Run"#\n\x10StartRunResponse\x12\x0f\n\x07message\x18\x01 \x01(\t"N\n\x10SubmitLogRequest\x12\x1c\n\x03log\x18\x01 \x01(\x0b\x32\x0f.baserun.v1.Log\x12\x1c\n\x03run\x18\x02 \x01(\x0b\x32\x0f.baserun.v1.Run"$\n\x11SubmitLogResponse\x12\x0f\n\x07message\x18\x01 \x01(\t"Q\n\x11SubmitSpanRequest\x12\x1e\n\x04span\x18\x01 \x01(\x0b\x32\x10.baserun.v1.Span\x12\x1c\n\x03run\x18\x02 \x01(\x0b\x32\x0f.baserun.v1.Run"%\n\x12SubmitSpanResponse\x12\x0f\n\x07message\x18\x01 \x01(\t"-\n\rEndRunRequest\x12\x1c\n\x03run\x18\x01 \x01(\x0b\x32\x0f.baserun.v1.Run"!\n\x0e\x45ndRunResponse\x12\x0f\n\x07message\x18\x01 \x01(\t"Q\n\x11SubmitEvalRequest\x12\x1e\n\x04\x65val\x18\x01 \x01(\x0b\x32\x10.baserun.v1.Eval\x12\x1c\n\x03run\x18\x02 \x01(\x0b\x32\x0f.baserun.v1.Run"%\n\x12SubmitEvalResponse\x12\x0f\n\x07message\x18\x01 \x01(\t"B\n\x15StartTestSuiteRequest\x12)\n\ntest_suite\x18\x01 \x01(\x0b\x32\x15.baserun.v1.TestSuite")\n\x16StartTestSuiteResponse\x12\x0f\n\x07message\x18\x01 \x01(\t"@\n\x13\x45ndTestSuiteRequest\x12)\n\ntest_suite\x18\x01 \x01(\x0b\x32\x15.baserun.v1.TestSuite"\'\n\x14\x45ndTestSuiteResponse\x12\x0f\n\x07message\x18\x01 \x01(\t"Y\n\x13StartSessionRequest\x12$\n\x07session\x18\x01 \x01(\x0b\x32\x13.baserun.v1.Session\x12\x1c\n\x03run\x18\x02 \x01(\x0b\x32\x0f.baserun.v1.Run"M\n\x14StartSessionResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12$\n\x07session\x18\x02 \x01(\x0b\x32\x13.baserun.v1.Session"9\n\x11\x45ndSessionRequest\x12$\n\x07session\x18\x01 \x01(\x0b\x32\x13.baserun.v1.Session"K\n\x12\x45ndSessionResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12$\n\x07session\x18\x02 \x01(\x0b\x32\x13.baserun.v1.Session"j\n\x1cSubmitTemplateVersionRequest\x12\x35\n\x10template_version\x18\x01 \x01(\x0b\x32\x1b.baserun.v1.TemplateVersion\x12\x13\n\x0b\x65nvironment\x18\x02 \x01(\t"\x8f\x01\n\x1dSubmitTemplateVersionResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x35\n\x10template_version\x18\x02 \x01(\x0b\x32\x1b.baserun.v1.TemplateVersion\x12&\n\x08template\x18\x03 \x01(\x0b\x32\x14.baserun.v1.Template"I\n\x18SubmitModelConfigRequest\x12-\n\x0cmodel_config\x18\x01 \x01(\x0b\x32\x17.baserun.v1.ModelConfig"[\n\x19SubmitModelConfigResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12-\n\x0cmodel_config\x18\x02 \x01(\x0b\x32\x17.baserun.v1.ModelConfig"6\n\x11SubmitUserRequest\x12!\n\x04user\x18\x01 \x01(\x0b\x32\x13.baserun.v1.EndUser"H\n\x12SubmitUserResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12!\n\x04user\x18\x02 \x01(\x0b\x32\x13.baserun.v1.EndUser"*\n\x13GetTemplatesRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t"?\n\x14GetTemplatesResponse\x12\'\n\ttemplates\x18\x01 \x03(\x0b\x32\x14.baserun.v1.Template"p\n\x18SubmitAnnotationsRequest\x12\x36\n\x0b\x61nnotations\x18\x01 \x01(\x0b\x32!.baserun.v1.CompletionAnnotations\x12\x1c\n\x03run\x18\x02 \x01(\x0b\x32\x0f.baserun.v1.Run",\n\x19SubmitAnnotationsResponse\x12\x0f\n\x07message\x18\x01 \x01(\t"O\n\x1aSubmitInputVariableRequest\x12\x31\n\x0einput_variable\x18\x01 \x01(\x0b\x32\x19.baserun.v1.InputVariable".\n\x1bSubmitInputVariableResponse\x12\x0f\n\x07message\x18\x01 \x01(\t2\x85\n\n\x11SubmissionService\x12\x45\n\x08StartRun\x12\x1b.baserun.v1.StartRunRequest\x1a\x1c.baserun.v1.StartRunResponse\x12H\n\tSubmitLog\x12\x1c.baserun.v1.SubmitLogRequest\x1a\x1d.baserun.v1.SubmitLogResponse\x12K\n\nSubmitSpan\x12\x1d.baserun.v1.SubmitSpanRequest\x1a\x1e.baserun.v1.SubmitSpanResponse\x12?\n\x06\x45ndRun\x12\x19.baserun.v1.EndRunRequest\x1a\x1a.baserun.v1.EndRunResponse\x12K\n\nSubmitEval\x12\x1d.baserun.v1.SubmitEvalRequest\x1a\x1e.baserun.v1.SubmitEvalResponse\x12W\n\x0eStartTestSuite\x12!.baserun.v1.StartTestSuiteRequest\x1a".baserun.v1.StartTestSuiteResponse\x12Q\n\x0c\x45ndTestSuite\x12\x1f.baserun.v1.EndTestSuiteRequest\x1a .baserun.v1.EndTestSuiteResponse\x12Q\n\x0cStartSession\x12\x1f.baserun.v1.StartSessionRequest\x1a .baserun.v1.StartSessionResponse\x12K\n\nEndSession\x12\x1d.baserun.v1.EndSessionRequest\x1a\x1e.baserun.v1.EndSessionResponse\x12l\n\x15SubmitTemplateVersion\x12(.baserun.v1.SubmitTemplateVersionRequest\x1a).baserun.v1.SubmitTemplateVersionResponse\x12`\n\x11SubmitModelConfig\x12$.baserun.v1.SubmitModelConfigRequest\x1a%.baserun.v1.SubmitModelConfigResponse\x12K\n\nSubmitUser\x12\x1d.baserun.v1.SubmitUserRequest\x1a\x1e.baserun.v1.SubmitUserResponse\x12Q\n\x0cGetTemplates\x12\x1f.baserun.v1.GetTemplatesRequest\x1a .baserun.v1.GetTemplatesResponse\x12`\n\x11SubmitAnnotations\x12$.baserun.v1.SubmitAnnotationsRequest\x1a%.baserun.v1.SubmitAnnotationsResponse\x12\x66\n\x13SubmitInputVariable\x12&.baserun.v1.SubmitInputVariableRequest\x1a\'.baserun.v1.SubmitInputVariableResponseb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.baserun_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_STATUS"]._serialized_start = 66
    _globals["_STATUS"]._serialized_end = 222
    _globals["_STATUS_STATUSCODE"]._serialized_start = 138
    _globals["_STATUS_STATUSCODE"]._serialized_end = 222
    _globals["_TOOLFUNCTION"]._serialized_start = 224
    _globals["_TOOLFUNCTION"]._serialized_end = 271
    _globals["_TOOLCALL"]._serialized_start = 273
    _globals["_TOOLCALL"]._serialized_end = 353
    _globals["_MESSAGE"]._serialized_start = 356
    _globals["_MESSAGE"]._serialized_end = 548
    _globals["_RUN"]._serialized_start = 551
    _globals["_RUN"]._serialized_end = 940
    _globals["_RUN_RUNTYPE"]._serialized_start = 871
    _globals["_RUN_RUNTYPE"]._serialized_end = 924
    _globals["_LOG"]._serialized_start = 942
    _globals["_LOG"]._serialized_end = 1041
    _globals["_ENDUSER"]._serialized_start = 1043
    _globals["_ENDUSER"]._serialized_end = 1084
    _globals["_MODEL"]._serialized_start = 1086
    _globals["_MODEL"]._serialized_end = 1157
    _globals["_MODELCONFIG"]._serialized_start = 1160
    _globals["_MODELCONFIG"]._serialized_end = 1403
    _globals["_SPAN"]._serialized_start = 1406
    _globals["_SPAN"]._serialized_end = 3107
    _globals["_EVAL"]._serialized_start = 3109
    _globals["_EVAL"]._serialized_end = 3226
    _globals["_CHECK"]._serialized_start = 3228
    _globals["_CHECK"]._serialized_end = 3337
    _globals["_FEEDBACK"]._serialized_start = 3339
    _globals["_FEEDBACK"]._serialized_end = 3435
    _globals["_COMPLETIONANNOTATIONS"]._serialized_start = 3438
    _globals["_COMPLETIONANNOTATIONS"]._serialized_end = 3642
    _globals["_TESTSUITE"]._serialized_start = 3645
    _globals["_TESTSUITE"]._serialized_end = 3793
    _globals["_TEMPLATE"]._serialized_start = 3796
    _globals["_TEMPLATE"]._serialized_end = 4132
    _globals["_TEMPLATE_TEMPLATETYPE"]._serialized_start = 4006
    _globals["_TEMPLATE_TEMPLATETYPE"]._serialized_end = 4113
    _globals["_TEMPLATEVERSION"]._serialized_start = 4135
    _globals["_TEMPLATEVERSION"]._serialized_end = 4383
    _globals["_TEMPLATEMESSAGE"]._serialized_start = 4386
    _globals["_TEMPLATEMESSAGE"]._serialized_end = 4522
    _globals["_SESSION"]._serialized_start = 4525
    _globals["_SESSION"]._serialized_end = 4716
    _globals["_INPUTVARIABLE"]._serialized_start = 4719
    _globals["_INPUTVARIABLE"]._serialized_end = 4890
    _globals["_STARTRUNREQUEST"]._serialized_start = 4892
    _globals["_STARTRUNREQUEST"]._serialized_end = 4939
    _globals["_STARTRUNRESPONSE"]._serialized_start = 4941
    _globals["_STARTRUNRESPONSE"]._serialized_end = 4976
    _globals["_SUBMITLOGREQUEST"]._serialized_start = 4978
    _globals["_SUBMITLOGREQUEST"]._serialized_end = 5056
    _globals["_SUBMITLOGRESPONSE"]._serialized_start = 5058
    _globals["_SUBMITLOGRESPONSE"]._serialized_end = 5094
    _globals["_SUBMITSPANREQUEST"]._serialized_start = 5096
    _globals["_SUBMITSPANREQUEST"]._serialized_end = 5177
    _globals["_SUBMITSPANRESPONSE"]._serialized_start = 5179
    _globals["_SUBMITSPANRESPONSE"]._serialized_end = 5216
    _globals["_ENDRUNREQUEST"]._serialized_start = 5218
    _globals["_ENDRUNREQUEST"]._serialized_end = 5263
    _globals["_ENDRUNRESPONSE"]._serialized_start = 5265
    _globals["_ENDRUNRESPONSE"]._serialized_end = 5298
    _globals["_SUBMITEVALREQUEST"]._serialized_start = 5300
    _globals["_SUBMITEVALREQUEST"]._serialized_end = 5381
    _globals["_SUBMITEVALRESPONSE"]._serialized_start = 5383
    _globals["_SUBMITEVALRESPONSE"]._serialized_end = 5420
    _globals["_STARTTESTSUITEREQUEST"]._serialized_start = 5422
    _globals["_STARTTESTSUITEREQUEST"]._serialized_end = 5488
    _globals["_STARTTESTSUITERESPONSE"]._serialized_start = 5490
    _globals["_STARTTESTSUITERESPONSE"]._serialized_end = 5531
    _globals["_ENDTESTSUITEREQUEST"]._serialized_start = 5533
    _globals["_ENDTESTSUITEREQUEST"]._serialized_end = 5597
    _globals["_ENDTESTSUITERESPONSE"]._serialized_start = 5599
    _globals["_ENDTESTSUITERESPONSE"]._serialized_end = 5638
    _globals["_STARTSESSIONREQUEST"]._serialized_start = 5640
    _globals["_STARTSESSIONREQUEST"]._serialized_end = 5729
    _globals["_STARTSESSIONRESPONSE"]._serialized_start = 5731
    _globals["_STARTSESSIONRESPONSE"]._serialized_end = 5808
    _globals["_ENDSESSIONREQUEST"]._serialized_start = 5810
    _globals["_ENDSESSIONREQUEST"]._serialized_end = 5867
    _globals["_ENDSESSIONRESPONSE"]._serialized_start = 5869
    _globals["_ENDSESSIONRESPONSE"]._serialized_end = 5944
    _globals["_SUBMITTEMPLATEVERSIONREQUEST"]._serialized_start = 5946
    _globals["_SUBMITTEMPLATEVERSIONREQUEST"]._serialized_end = 6052
    _globals["_SUBMITTEMPLATEVERSIONRESPONSE"]._serialized_start = 6055
    _globals["_SUBMITTEMPLATEVERSIONRESPONSE"]._serialized_end = 6198
    _globals["_SUBMITMODELCONFIGREQUEST"]._serialized_start = 6200
    _globals["_SUBMITMODELCONFIGREQUEST"]._serialized_end = 6273
    _globals["_SUBMITMODELCONFIGRESPONSE"]._serialized_start = 6275
    _globals["_SUBMITMODELCONFIGRESPONSE"]._serialized_end = 6366
    _globals["_SUBMITUSERREQUEST"]._serialized_start = 6368
    _globals["_SUBMITUSERREQUEST"]._serialized_end = 6422
    _globals["_SUBMITUSERRESPONSE"]._serialized_start = 6424
    _globals["_SUBMITUSERRESPONSE"]._serialized_end = 6496
    _globals["_GETTEMPLATESREQUEST"]._serialized_start = 6498
    _globals["_GETTEMPLATESREQUEST"]._serialized_end = 6540
    _globals["_GETTEMPLATESRESPONSE"]._serialized_start = 6542
    _globals["_GETTEMPLATESRESPONSE"]._serialized_end = 6605
    _globals["_SUBMITANNOTATIONSREQUEST"]._serialized_start = 6607
    _globals["_SUBMITANNOTATIONSREQUEST"]._serialized_end = 6719
    _globals["_SUBMITANNOTATIONSRESPONSE"]._serialized_start = 6721
    _globals["_SUBMITANNOTATIONSRESPONSE"]._serialized_end = 6765
    _globals["_SUBMITINPUTVARIABLEREQUEST"]._serialized_start = 6767
    _globals["_SUBMITINPUTVARIABLEREQUEST"]._serialized_end = 6846
    _globals["_SUBMITINPUTVARIABLERESPONSE"]._serialized_start = 6848
    _globals["_SUBMITINPUTVARIABLERESPONSE"]._serialized_end = 6894
    _globals["_SUBMISSIONSERVICE"]._serialized_start = 6897
    _globals["_SUBMISSIONSERVICE"]._serialized_end = 8182
# @@protoc_insertion_point(module_scope)
